=========
Changelog
=========

0.2.4 (2025-09-17)
==================

**Project Maintenance**

* Allow django greater than 4


0.2.3 (2025-02-27)
==================

**Bugfixes and QoL Changes**

* fix crash when page menu is empty

**Documentation**

* Add changelog

0.2.2 (2025-02-17)
==================

**Bugfixes and QoL Changes**

* Fix export not appearing on CMS pages

0.2.1 (2024-12-16)
===================

**Bugfixes and QoL Changes**

* Support new placeholders ands static alias


**Project maintenance**

* Correcting PyPI links
* Pinning ``djangocms-page-meta`` to released version


0.2.0 (2024-12-09)
==================

**New features**

* Add support for Django CMS 4

**Breaking changes**

* Remove CMS 3 support

**Project Maintenance**

* Remove django 3.2 deprecations
* Fix tests
* Move test app
* Fix documentation in CI
* Fix CI code quality
* Change to pyproject.toml
* Add pycharm files to .gitignore
* Fix Isort
* Added a model & factories
* Updating tox configuration

0.1.6 (2020-10-13)
==================

* Made sure that the children will be loaded in


0.1.5 (2018-10-10)
==================

0.1.4 (2018-10-10)
==================

0.1.3 (2018-10-09)
==================

0.1.1 (2018-10-05)
==================

0.1.0 (2018-08-30)
==================

* Open sourced
